summaryrefslogtreecommitdiff
path: root/framework/Web/UI/WebControls
diff options
context:
space:
mode:
authorxue <>2006-05-01 15:40:31 +0000
committerxue <>2006-05-01 15:40:31 +0000
commitc5983c0440913cd67f3744c7dda3c3bfc7eee0ed (patch)
treed20f9c309cb212d309231d8a990fff11b512e973 /framework/Web/UI/WebControls
parentddfafaac2c1f18aca0fda3b4157acd935b9ac9a2 (diff)
Merge from 3.0 branch till 1004.
Diffstat (limited to 'framework/Web/UI/WebControls')
-rw-r--r--framework/Web/UI/WebControls/TBaseValidator.php11
-rw-r--r--framework/Web/UI/WebControls/TValidationSummary.php6
2 files changed, 8 insertions, 9 deletions
diff --git a/framework/Web/UI/WebControls/TValidationSummary.php b/framework/Web/UI/WebControls/TValidationSummary.php
index aa46142b..87821292 100644
--- a/framework/Web/UI/WebControls/TValidationSummary.php
+++ b/framework/Web/UI/WebControls/TValidationSummary.php
@@ -258,7 +258,7 @@ class TValidationSummary extends TWebControl
* @return TValidationSummaryClientScript client-side validation summary
* event options.
*/
- public function getClientValidation()
+ public function getClientSide()
{
if(is_null($this->_clientScript))
$this->_clientScript = $this->createClientScript();
@@ -376,8 +376,8 @@ class TValidationSummary extends TWebControl
*
* Client-side validation summary events such as {@link setOnHideSummary
* OnHideSummary} and {@link setOnShowSummary OnShowSummary} can be modified
- * through the {@link TBaseValidator:: getClientValidation ClientValidation}
- * property of a validation summary.
+ * through the {@link TBaseValidator:: getClientSide ClientSide} property of a
+ * validation summary.
*
* The <tt>OnHideSummary</tt> event is raise when the validation summary
* requests to hide the messages.
diff --git a/framework/Web/UI/WebControls/TBaseValidator.php b/framework/Web/UI/WebControls/TBaseValidator.php
index a63941db..ea1a5836 100644
--- a/framework/Web/UI/WebControls/TBaseValidator.php
+++ b/framework/Web/UI/WebControls/TBaseValidator.php
@@ -42,7 +42,7 @@
* be displayed. Error display is controlled by {@link setDisplay Display} property.
*
* You can also customized the client-side behaviour by adding javascript
- * code to the subproperties of the {@link getClientValidation ClientValidation}
+ * code to the subproperties of the {@link getClientSide ClientSide}
* property. See quickstart documentation for further details.
*
* You can also place a {@link TValidationSummary} control on a page to display error messages
@@ -176,7 +176,7 @@ abstract class TBaseValidator extends TLabel implements IValidator
*
* @return TValidatorClientScript javascript validator event options.
*/
- public function getClientValidation()
+ public function getClientSide()
{
if(is_null($this->_clientScript))
$this->_clientScript = $this->createClientScript();
@@ -494,10 +494,9 @@ abstract class TBaseValidator extends TLabel implements IValidator
* TValidatorClientScript class.
*
* Client-side validator events can be modified through the {@link
* TBaseValidator::getClientValidation ClientValidation} property of a
* validator. The subproperties of ClientValidation are those of the
* TValidatorClientScript properties. The client-side validator supports the
* following events.
*
* The <tt>OnValidate</tt> event is raise before the validator validation
* functions are called.
@@ -494,10 +494,9 @@ abstract class TBaseValidator extends TLabel implements IValidator
*
* Client-side validator events can be modified through the {@link
- * TBaseValidator::getClientValidation ClientValidation} property of a
- * validator. The subproperties of ClientValidation are those of the
- * TValidatorClientScript properties. The client-side validator supports the
- * following events.
+ * TBaseValidator::getClientSide ClientSide} property of a validator. The
+ * subproperties of ClientSide are those of the TValidatorClientScript
+ * properties. The client-side validator supports the following events.
*
* The <tt>OnValidate</tt> event is raise before the validator validation